@@ -44,6 +44,8 @@ from .type_mapping import convert_basic_types
 
 T = typing.TypeVar("T")
 
+_immutable_types = (int, float, str, tuple, bool, enum.Enum)
+
 
 class ImmutableMixin:
     """
@@ -54,7 +56,26 @@ class ImmutableMixin:
     _instance = None
 
     def _get_defensive_copy_if_needed(self, value):
-        return deepcopy(value) if self._is_immutable() else value
+        return (
+            deepcopy(value)
+            if (
+                not isinstance(
+                    value,
+                    (
+                        int,
+                        float,
+                        str,
+                        tuple,
+                        bool,
+                        enum.Enum,
+                        ImmutableMixin,
+                        ImmutableStructure,
+                    ),
+                )
+                and self._is_immutable()
+            )
+            else value
+        )
 
     def _is_immutable(self):
         if getattr(self._field_definition, "_immutable", False):
@@ -417,7 +438,6 @@ class Field(UniqueMixin, metaclass=FieldMeta):
                         str,
                         bool,
                         enum.Enum,
-                        Field,
                         ImmutableStructure,
                     ),
                 )
@@ -432,9 +452,11 @@ class Field(UniqueMixin, metaclass=FieldMeta):
                     f"{self._name} cannot be immutable, as its type does not support pickle."
                 )
         else:
-            self.__manage_uniqueness_for_field__(instance, value)
+            if TypedPyDefaults.uniqueness_features_enabled:
+                self.__manage_uniqueness_for_field__(instance, value)
             instance.__dict__[self._name] = value
-            instance.__manage__uniqueness_of_all_fields__()
+            if TypedPyDefaults.uniqueness_features_enabled:
+                instance.__manage__uniqueness_of_all_fields__()
         if getattr(instance, "_instantiated", False) and not getattr(
             instance, "_skip_validation", False
         ):
@@ -982,8 +1004,9 @@ class Structure(UniqueMixin, metaclass=StructMeta):
 
         self.__validate__()
         self._instantiated = True
-        self.__manage_uniqueness__()
-        self.__manage__uniqueness_of_all_fields__()
+        if TypedPyDefaults.uniqueness_features_enabled:
+            self.__manage_uniqueness__()
+            self.__manage__uniqueness_of_all_fields__()
 
     def _set_defaults(self, defaults_fields, field_by_name):
         for field_name in defaults_fields:
@@ -1011,7 +1034,6 @@ class Structure(UniqueMixin, metaclass=StructMeta):
                         str,
                         bool,
                         enum.Enum,
-                        Field,
                         ImmutableStructure,
                     ),
                 )
@@ -1053,6 +1075,7 @@ class Structure(UniqueMixin, metaclass=StructMeta):
             getattr(self, "_instantiated", False)
             and not _is_dunder(key)
             and not _is_sunder(key)
+            and TypedPyDefaults.uniqueness_features_enabled
         ):
             self.__manage_uniqueness__()
 
@@ -1130,7 +1153,19 @@ class Structure(UniqueMixin, metaclass=StructMeta):
         pass
 
     def __deepcopy__(self, memo):
-        if isinstance(self, ImmutableStructure) and getattr(self, IS_IMMUTABLE, False):
+        if isinstance(
+            self,
+            (
+                int,
+                float,
+                str,
+                tuple,
+                bool,
+                enum.Enum,
+                ImmutableMixin,
+                ImmutableStructure,
+            ),
+        ) and getattr(self, IS_IMMUTABLE, False):
             return self
         cls = self.__class__
         result = cls.__new__(cls)
